package denim;

import beast.core.BEASTObject;
import beast.core.Description;
import beast.core.Input;
import beast.core.parameter.RealParameter;

/*
 * Created by GRJ on 02/06/2017.
 */

@Description("A component in a mixture of gamma distributions.")

public class GammaComponent extends BEASTObject {
    @SuppressWarnings({"CanBeFinal", "WeakerAccess"})
    public Input<RealParameter> weight =
            new Input<>("weight",
                    "weight of component in mixture of gamma distributions", Input.Validate.REQUIRED);

    @SuppressWarnings({"CanBeFinal", "WeakerAccess"})
    public Input<RealParameter>  shape =
            new Input<>("shape",
                    "shape parameter of a gamma distribution", Input.Validate.REQUIRED);

    @SuppressWarnings({"CanBeFinal", "WeakerAccess"})
    public Input<RealParameter> scale =
            new Input<>("scale",
                    "scale parameter of a gamma distributions", Input.Validate.REQUIRED);

    // gamma pdf is parameterized as  b^a/Gamma(a)  x^(a-1)  exp(-bx)



    @Override
    public void initAndValidate() {
        if (getWeight() <= 0.0) {
            throw new IllegalArgumentException("weight must be positive");
        }
        if (getShape() <= 0.0) {
            throw new IllegalArgumentException("shape must be positive");
        }
        if (getScale() <= 0.0) {
            throw new IllegalArgumentException("scale must be positive");
        }
    }

    private double getWeight() { return weight.get().getValue(); }
    double getShape() { return shape.get().getValue(); }
    double getScale() { return scale.get().getValue(); }



/*
    void normalizeWeight(double total) {
        Double [] normWt = new Double[1];
        normWt[0] = weight.get().getValue() / total;
        RealParameter normalizedWeight = new RealParameter(normWt);
        weight.get().assignFromWithoutID(normalizedWeight);
    }*/
}
