package denim;

/*
 * Created by Work on 27/10/2016.
 */
import beast.core.BEASTObject;
import beast.core.Description;
import beast.core.Input;
import beast.core.parameter.RealParameter;

/**
 *  Created by Graham Jones on 20/08/2014.
 */

@Description("A component in a mixture of inverse gamma distributions.")


public class InverseGammaComponent extends BEASTObject {
    @SuppressWarnings({"CanBeFinal", "WeakerAccess"})
    public Input<RealParameter> weight =
            new Input<>("weight",
                    "weight of component in mixture of inverse gammas", Input.Validate.REQUIRED);

    @SuppressWarnings({"CanBeFinal", "WeakerAccess"})
    public Input<RealParameter>  alpha =
            new Input<>("alpha",
                    "shape parameter of an inverse gamma", Input.Validate.REQUIRED);

    @SuppressWarnings({"CanBeFinal", "WeakerAccess"})
    public Input<RealParameter> beta =
            new Input<>("beta",
                    "scale parameter of an inverse gamma", Input.Validate.REQUIRED);

    // inv gamma pdf is parameterized as  b^a/Gamma(a)  x^(-a-1)  exp(-b/x)
    // mean is b/(a-1) if a>1, var is  b^2/((a-1)^2 (a-2)) if a>2.



    @Override
    public void initAndValidate() {
        if (getWeight() <= 0.0) {
            throw new IllegalArgumentException("weight must be positive");
        }
        if (getAlpha() <= 0.0) {
            throw new IllegalArgumentException("alpha must be positive");
        }
        if (getBeta() <= 0.0) {
            throw new IllegalArgumentException("beta must be positive");
        }
    }

    double getWeight() { return weight.get().getValue(); }
    double getAlpha() { return alpha.get().getValue(); }
    double getBeta() { return beta.get().getValue(); }

    void normalizeWeight(double total) {
        Double [] normWt = new Double[1];
        normWt[0] = weight.get().getValue() / total;
        RealParameter normalizedWeight = new RealParameter(normWt);
        weight.get().assignFromWithoutID(normalizedWeight);
    }

}
